@@ -838,7 +838,7 @@ parse_config_value (char *cfgline, unsigned line)
 {
 	static char val[WORDSIZE0];
 	char *ptr;
-	const char regex[] = "[a-z]+[= \t]+(.*)[ \t]*$";
+	const char regex[] = "[a-z0-9]+[= \t]+(.*)[ \t]*$";
 	regex_t preg;
 	regmatch_t matches[3];
 
@@ -870,7 +870,7 @@ parse_config (void)
 	extern options_t opt;
 	
 	const char comment[] = "!#\n";
-	char buffer[HUGE0], *ptr;
+	char buffer[HUGE0], *ptr, *tmp;
 	const char *cfg = opt.config;
 	FILE *fd = fopen (cfg, "r");
 	int l, line = 0;
@@ -893,10 +893,11 @@ parse_config (void)
 		line++;
 		ptr = buffer;
 
-		while (isblank (*ptr)) ptr++;
+		while (isblank (*ptr))
+                    ptr++;
 		
 		if (*ptr == 0x00 || strchr (comment, *ptr))
-		 continue;
+                    continue;
 
 		l = strlen (ptr);
 		if (--l > 0 && ptr[l] == '\n')
@@ -916,16 +917,58 @@ parse_config (void)
 		{
 			parse_config_blacklist (ptr, line);
 		}
-        else
-        if (!strncasecmp (ptr, "cache", 5))
-        {
-            opt.cache = xstrdup (parse_config_value (ptr, line));
-        }
+                else
+                if (!strncasecmp (ptr, "cache", 5))
+                {
+                    opt.cache = xstrdup (parse_config_value (ptr, line));
+                }
+		else
+                if (!strncasecmp (ptr, "upgrade_replacing_official", 26))
+                {
+                    tmp = parse_config_value (ptr, line);
+                    if (!strcasecmp (tmp, "no"))
+                    {
+                        opt.upgrade_replacing_official = false;
+                    }
+                    else
+                    if (strcasecmp (tmp, "yes"))
+                    {
+                        cfg_syntax_error (ptr, line);
+                    }
+                }
+		else
+                if (!strncasecmp (ptr, "wget", 4))
+                {
+                    tmp = parse_config_value (ptr, line);
+                    if (!strcasecmp (tmp, "yes"))
+                    {
+                        opt.wget = true;
+                    }
+                    else
+                    if (strcasecmp (tmp, "no"))
+                    {
+                        cfg_syntax_error (ptr, line);
+                    }
+                }
+		else
+                if (!strncasecmp (ptr, "slackware64", 11))
+                {
+                    tmp = parse_config_value (ptr, line);
+                    if (!strcasecmp (tmp, "yes"))
+                    {
+                        opt.slackware64 = true;
+                    }
+                    else
+                    if (strcasecmp (tmp, "no"))
+                    {
+                        cfg_syntax_error (ptr, line);
+                    }
+                }
 		else
 		{
 			cfg_syntax_error (ptr, line);
 		}
-    }
+        }
 
 	mirror_check ();
 	mirror_fix_order ();
@@ -960,6 +1003,7 @@ parse_options (int argc, char **argv)
 	opt.blacklist        = true;
 	opt.hash             = true;
 	opt.config           = xstrdup (CONFIGFILE);
+    opt.upgrade_replacing_official = true;
 
     /* Set default cache if nothing specified in config file */
     if (opt.cache == NULL) {
@@ -1071,7 +1115,7 @@ parse_options (int argc, char **argv)
 	    break;
 	case 'c':
 	    free (opt.config);
-        opt.config = xstrdup (optarg);
+            opt.config = xstrdup (optarg);
 	    break;
 	case 'd':		/* check for missing shared libraries */
 	    opt.shared_dep  = true;
@@ -1181,7 +1225,6 @@ parse_options (int argc, char **argv)
 	 _error (3, "Invalid argument \"", opt.package, "\".\n"
 	            "Use -e switch to enable regex.\n");
 	 
-    
     return EXIT_SUCCESS;
 }
 
