@@ -222,6 +222,28 @@ netstat (int init, time_t pause, unsigned long received, unsigned long filesz)
 
     return buffer;
 }
+
+int
+get_file_over_wget (net_t *netpolicy,bool is_http)
+{
+	char buffer[BUFFSIZE0];
+	int out;
+	fprintf (stdout, "%s...", netpolicy->msg);
+        fflush (stdout);
+        if(is_http){
+		snprintf(buffer,BUFFSIZE, "/usr/bin/wget -q -O '%s' 'http://%s:%d/%s'",
+                    netpolicy->destpath, netpolicy->hostname, netpolicy->port, netpolicy->srcpath);
+	}else{
+		snprintf(buffer,BUFFSIZE, "/usr/bin/wget -q -O '%s' 'ftp://%s:%d/%s'",
+                    netpolicy->destpath, netpolicy->hostname, netpolicy->port, netpolicy->srcpath);
+	}
+        out=system(buffer);
+	if(out==0){
+		return shutdown_net_t(netpolicy, FILE_DOWNLOADED, "ok");
+	}else{
+		return shutdown_net_t(netpolicy, out, "Wget Error!");
+	}
+}
     
 int
 get_file_over_http (net_t *netpolicy)
@@ -579,12 +601,21 @@ get_pkg (pkg_t *package)
     snprintf (netpolicy.srcpath,  BUFFSIZE, "%s/%s/%s", path, loc, name);
     snprintf (netpolicy.destpath, BUFFSIZE, "%s/%s", cache, name);
 
-    switch (REPOS[r].proto_t) {
-        case proto_http: return get_file_over_http (&netpolicy);  break;
-        case proto_ftp:  return get_file_over_ftp  (&netpolicy);  break;
-        case proto_file: return get_file_over_fs   (&netpolicy);  break;
-        default:   slassert (NULL);                               break;
-        }
+    if(opt.wget){ 
+	    switch (REPOS[r].proto_t) {
+		case proto_http: return get_file_over_wget (&netpolicy,true);  break;
+		case proto_ftp:  return get_file_over_wget (&netpolicy,false);  break;
+		case proto_file: return get_file_over_fs   (&netpolicy);  break;
+		default:   slassert (NULL);                               break;
+	    }
+    }else{
+	    switch (REPOS[r].proto_t) {
+		case proto_http: return get_file_over_http (&netpolicy);  break;
+		case proto_ftp:  return get_file_over_ftp  (&netpolicy);  break;
+		case proto_file: return get_file_over_fs   (&netpolicy);  break;
+		default:   slassert (NULL);                               break;
+		}
+    }
 
     return -1;
 }
