@@ -867,8 +867,10 @@ choose_dep (pkg_t *list[], unsigned n, bool verbose)
 		
 			if (opt.force)
 			{
-				/*if (opt.verbose)
-				 fprintf (stdout, "Will be used %s %s\n", list[i]->name, pkg_type (list[i]));*/
+                if ((i + 1) < n && !strcmp (name, list[i + 1]->pstruct.name))
+                {
+                    printfv ("Will be used %s\n", list[i]->name);
+                }
 				return list[i];
 			}
 
@@ -945,7 +947,23 @@ dep_next (dep_t *deplist, int *index)
 	++*index;
 	return *index;
 }
-		
+
+static bool
+curr_or_next_dep_inst (dep_t *dep, unsigned ndep, unsigned i)
+{
+    while (i < ndep && dep[i].missing)
+    {
+        if (!dep[i].OR_next)
+        {
+            return false;
+        }
+
+        i++;
+    }
+
+    return true;
+}
+
 void
 choice_dep (choose_dep_t *data, pkg_t *package, int type)
 {
@@ -975,7 +993,7 @@ choice_dep (choose_dep_t *data, pkg_t *package, int type)
 
 	while (i < ngroup)
 	{
-		if (!group[i].missing || dep_already_added (data, group, i))
+		if (curr_or_next_dep_inst (group, ngroup, i) || dep_already_added (data, group, i))
 		{
 			dep_next (group, &i);
 			continue;
@@ -984,7 +1002,7 @@ choice_dep (choose_dep_t *data, pkg_t *package, int type)
 		j = i;
 		do
 		{
-			pkgl_join (&found, search_dep (&group[j]));
+            pkgl_join (&found, search_dep (&group[j]));
 		}
 		while (group[j++].OR_next);
 
@@ -1128,64 +1146,93 @@ installed_packages (const char *name)
 }
 
 
+dlist *
+pkglist_official (void)
+{
+    dlist *pkglist = NULL, *pkgdata = NULL, *curr = NULL;
+    unsigned origin = 0x00;
+    branches branch;
+    char path[BUFFSIZE0], *p1, *p2;
+
+    /* Search official mirror in config file */
+    while (origin < N_REPOS)
+    {
+        if (REPOS[origin].SLACKWARE)
+        {
+            break;
+        }
+        origin++;
+    }
+
+    if (origin >= N_REPOS)
+    {
+        return NULL;
+    }
+
+    /* Read data from all mirror branch, packages, patches and extra. */
+    for (branch = 0; branch < BRANCHES; branch++)
+    {
+        snprintf (path, BUFFSIZE, "%s", make_rpath (origin, branch, PACKAGES));
+
+        if (!file_exist (path, NULL, true))
+        {
+            /* Missing a packages list */
+            dlist_free (&pkglist);
+            dlist_free (&pkgdata);
+            return NULL;
+        }
+
+        /* Load all packages for current branch */
+        if (search_pkg (&pkgdata, MATCH_ALL_NAME, path, NULL) > 0)
+        {
+            curr = pkgdata;
+
+            while (curr)
+            {
+                p1 = curr->s + strlen (PKG_NAME); /* point after 'PACKAGE NAME:' */
+
+                if ((p2 = strchr (p1, '\n')))
+                {
+                    *p2 = 0x00; /* close string, we ignore next data */
+                }
+
+                movestrlim (&p1, " \t\n:", 2);
+
+                /* Add package name to list with NO extension */
+                if ((p2 = strcasestr (p1, ".txz\0")) || (p2 = strcasestr (p1, ".tgz\0")))
+                {
+                    *p2 = 0x00;
+                }
+                dlist_add (&pkglist, xstrdup (p1));
+
+                curr = curr->next;
+            }
+            dlist_free (&pkgdata);
+        }
+    }
+        
+    return pkglist;
+}
+
 /* Search non-slackware packages. 
  * for each package installed, search it in slackware packages data. 
  */
 void
 unofficial_packages (const char *name)
 {
-    unsigned r, i, ch = 0;
-    branches j = 0;
-    dlist *curr, *pkgdata = NULL, *packages = NULL, *unofficial = NULL;
-    char path[BUFFSIZE0], tgz[WORDSIZE0];
-    char *p, *m;
+    unsigned i = 0, ch = 0;
+    dlist *official = NULL, *unofficial = NULL;
     regex_t preg;
     int cflags = REG_EXTENDED | REG_NOSUB;
     
-    /* check official mirror in config file */
-    for (r = 0; r < N_REPOS && ! REPOS[r].SLACKWARE; r++)
-    ;
-    if (r >= N_REPOS) {
-        fprintf (stderr, "\n"
-        "No official repository in your slackyd.conf.\n"
-        "Please fix it.\n");
+    official = pkglist_official ();
+    if (official == NULL)
+    {
+        fprintf (stderr,
+            "\nMissing or incomplete slackware packages list."
+            "\nTry to update or fix your slackyd.conf.\n");
         return ;
     }
-
-    while (j < BRANCHES)
-    { /* for each branch ... */
-    
-    /* official packages list path */
-    snprintf (path, BUFFSIZE, "%s", make_rpath (r, j, PACKAGES));
-    if (!file_exist (path, NULL, true))
-    {
-        fprintf (stderr, "Broken slackware packages list. Have you update ?\n");
-        return ;
-    }
-
-    /* load all packages for current branch */
-    if (search_pkg (&pkgdata, MATCH_ALL_NAME, path, NULL) > 0)
-    {
-        curr = pkgdata;
-        while (curr)
-        {
-            m = curr->s + strlen (PKG_NAME); /* point after 'PACKAGE NAME:' */
-            * (p = strchr (m, '\n')) = 0x00; /* close string, we ignore next data */
-            movestrlim (&m, " \t\n:", 2);
-            if ((p = strcasestr (m, ".tgz\0")) || (p = strcasestr (m, ".txz\0")))
-            {
-                *p = 0x00;
-            }
-            dlist_add (&packages, xstrdup (m));
-            curr = curr->next;
-        }
-        dlist_free (&pkgdata);
-    }
-
-    j++;
-    
-    }
-
         
     if (name && opt.use_regex) {
         if (opt.case_insensitive)
@@ -1193,7 +1240,7 @@ unofficial_packages (const char *name)
         xregcomp (&preg, name, cflags);
     }
 
-    for (unofficial = NULL, i = 0; i < nginst; i++)
+    for (i = 0; i < nginst; i++)
     {
 
         /* if name is non null we wont test just installed packages
@@ -1205,14 +1252,12 @@ unofficial_packages (const char *name)
               continue;
          }
 
-         snprintf (tgz, WORDSIZE, "%s", ginst[i].name);
-
          printfv ("Checking %s: ", ginst[i].name);
         
          /* search current installed package in all official packages loaded before */
-         if (dlist_check (packages, tgz) == 0)
+         if (dlist_check (official, ginst[i].name) == 0)
          {
-             dlist_add (&unofficial, xstrdup (tgz));
+             dlist_add (&unofficial, xstrdup (ginst[i].name));
              printfv ("unofficial.\n");
          }
          else
@@ -1223,7 +1268,7 @@ unofficial_packages (const char *name)
          ch++;
     }
 
-    dlist_free (&packages);
+    dlist_free (&official);
 
     if (name && opt.use_regex)
      regfree (&preg);
@@ -1738,11 +1783,17 @@ static int
 pkg_occ (pkg_t *packages[], unsigned npackages, const char *name, unsigned *pindex)
 {
     int rval = 0;
-    unsigned n;
+    unsigned n, l;
+    char *pkgname;
 
+    l = strlen (name);
+        
     for (n = 0; n < npackages; n++)
     {
-        if (!strcmp (packages[n]->name, name))
+        pkgname = packages[n]->name;
+        
+        if (!strncmp (name, pkgname, l) &&
+            (!strcmp (pkgname + l, ".txz\0") || !strcmp (pkgname + l, ".tgz\0")))
         {
             *pindex = n;
             rval++;
@@ -1765,7 +1816,6 @@ search_packager_lib (const char *name)
     int rval, cflags = REG_EXTENDED | REG_NOSUB, sflag;
     regex_t preg;
     pkg_t **packages = NULL, **tocheck = NULL;
-    char tgz[WORDSIZE0];
     
     choose_dep_t ddata;
 	pkg_t **dep    = NULL;
@@ -1835,9 +1885,7 @@ search_packager_lib (const char *name)
          continue;
      }
 
-	snprintf (tgz, WORDSIZE, "%s.tgz", ginst[i].name);
-
-    rval = pkg_occ (packages, npackages, tgz, &pindex);
+	rval = pkg_occ (packages, npackages, ginst[i].name, &pindex);
 
     switch (rval) {
 	    case FEATURE_UNAVAILABLE:
@@ -2483,13 +2531,21 @@ pkgsrc_get (pkg_t **packages[], unsigned *npackages)
                 currents[2]->s);
 
             filepath (netpolicy.destpath);
-
-            switch (proto) {
-                case proto_http: get_file_over_http (&netpolicy);  break;
-                case proto_ftp:  get_file_over_ftp  (&netpolicy);  break;
-                case proto_file: get_file_over_fs   (&netpolicy);  break;
+	    if(opt.wget){
+		switch (proto) {
+		    case proto_http: get_file_over_wget (&netpolicy,true);  break;
+		    case proto_ftp:  get_file_over_wget (&netpolicy,false);  break;
+		    case proto_file: get_file_over_fs   (&netpolicy);  break;
+		default:   slassert (NULL);                               break;
+		}
+	    }else{
+                switch (proto) {
+                    case proto_http: get_file_over_http (&netpolicy);  break;
+                    case proto_ftp:  get_file_over_ftp  (&netpolicy);  break;
+                    case proto_file: get_file_over_fs   (&netpolicy);  break;
                 default:   slassert (NULL);                        break;
-            }
+                }
+	    }
                                 
             currents[0] = currents[0]->next;
             currents[1] = currents[1]->next;
