@@ -20,7 +20,7 @@
  *      MA 02110-1301, USA.
  */
 #define _GNU_SOURCE
-#define SLACKYD_VERSION "0.1.13"
+#define SLACKYD_VERSION "0.1.13.3"
 
 #define DATADIR     "/var/slackyd"
 #define CONFIGFILE  "/etc/slackyd/slackyd.conf"
@@ -84,7 +84,7 @@
 #define MANIFEST            "MANIFEST"
 #define ZMANIFEST           "MANIFEST.bz2"
 #define SMANIFEST           "slackware/MANIFEST.bz2"
-
+#define SMANIFEST64         "slackware64/MANIFEST.bz2"
 
 #define MATCH_ALL_NAME              0x00
 #define MATCH_EXACTLY_NAME          0x01
@@ -420,6 +420,8 @@ int check_elf_libs
 	 unsigned *n_missing_libs, char *tgz);
 
 /* net.c */
+int get_file_over_wget
+    (net_t *netpolicy, bool is_http);
 int get_file_over_http
     (net_t *netpolicy);
 int get_file_over_ftp
@@ -490,6 +492,8 @@ int purge
 	(int flag);
 void installed_packages
 	(const char *name);
+dlist *pkglist_official
+    (void);
 void unofficial_packages
 	(const char *name);
 void obsolete_packages
