@@ -235,7 +235,7 @@ update_get_file (unsigned index, branches branch, const char *file)
          * file destination path.
          * In other case `file' and `dfile' will be same string !
          */
-         file  = SMANIFEST;
+         file  = (!opt.slackware64) ? SMANIFEST : SMANIFEST64;
          dfile = ZMANIFEST;
      }
     
@@ -280,13 +280,20 @@ update_get_file (unsigned index, branches branch, const char *file)
         break;
 	
 	}
-		
-    switch (REPOS[index].proto_t)
-    {
-        case proto_http: return get_file_over_http (&netpolicy);  break;
-        case proto_ftp:  return get_file_over_ftp  (&netpolicy);  break;
-        case proto_file: return get_file_over_fs   (&netpolicy);  break;
-        default:   slassert (NULL);                               break;
+    if(opt.wget){
+            switch (REPOS[index].proto_t) {
+                case proto_http: return get_file_over_wget (&netpolicy,true);  break;
+                case proto_ftp:  return get_file_over_wget (&netpolicy,false);  break;
+                case proto_file: return get_file_over_fs   (&netpolicy);  break;
+                default:   slassert (NULL);                               break;
+            }
+    }else{
+            switch (REPOS[index].proto_t) {
+		case proto_http: return get_file_over_http (&netpolicy);  break;
+		case proto_ftp:  return get_file_over_ftp  (&netpolicy);  break;
+		case proto_file: return get_file_over_fs   (&netpolicy);  break;
+		default:   slassert (NULL);                               break;
+	    }
     }
 
 	return 0;
@@ -493,23 +500,36 @@ search_new (const char *pkgname, upgrade_t *toupgrade[])
     regex_t preg;
     pkg_t **packages = NULL;
     unsigned npackages = 0x00;
+    dlist *official = NULL;
         
     fprintf (stdout, "Reading packages data: ");
     fflush (stdout);
 
+    /* If we won't upgrade official packages replacing it with extra packages
+     * load here the slackware list.
+     * Otherwise set it to NULL.
+     */
+    if (!opt.upgrade_replacing_official)
+    {
+        official = pkglist_official ();
+    }
+
     sflags = (pkgname && opt.use_regex) ? MATCH_USING_REGEX : MATCH_EXACTLY_NAME_INST;
 
     packages = pkgl2pkgt (search (sflags, pkgname), &npackages);  
 
     if (!npackages)
     {
-         if (!pkgname)
-          fprintf (stdout, "\n\n"
-          "No packages found !?\n"
-          "Try to update packages list.\n");
-         else
-          fprintf (stdout, "nothing to do for `%s'.\n", pkgname);
-         return EXIT_FAILURE;
+        if (!pkgname)
+        {
+            printf ("\n\nNo packages found !?\nTry to update packages list.\n");
+        }
+        else
+        {
+            printf ("nothing to do for `%s'.\n", pkgname);
+        }
+        dlist_free (&official);
+        return -1;
     }
  
     fprintf (stdout, "done.\n");
@@ -527,9 +547,9 @@ search_new (const char *pkgname, upgrade_t *toupgrade[])
 
     if ((pkgname && opt.use_regex  && regexec (&preg, ginst[i].name, 0, NULL, 0))
      || (pkgname && !opt.use_regex && !xstrstr (ginst[i].name, pkgname)))
-     {
-         continue;
-     }
+    {
+        continue;
+    }
      
     printfv ("Verifying %s: ", ginst[i].name);
     
@@ -538,11 +558,16 @@ search_new (const char *pkgname, upgrade_t *toupgrade[])
     for (j = 0; j < npackages; j++)
     {
 
-        /* if current available package haven't same name of current
-         * package installed, of if already installed, go to begin for()
+        /* If one of this case return to begin for() doing nothing:
+         *
+         * - current available package name not matched on current package installed
+         * - current available packages already installed
+         * - current available packages ins't official, current installed is unofficial
+         *   and opt.upgrade_replacing_official is false.
          */
         if (strcmp (packages[j]->pstruct.name, ginst[i].pstruct.name)
-          || pkg_u_installed (packages[j]->name))
+         || pkg_u_installed (packages[j]->name)
+         || (!opt.upgrade_replacing_official && !REPOS[packages[j]->N_REPO].SLACKWARE && dlist_check (official, ginst[i].name)))
         {
             continue;
         }
@@ -581,6 +606,8 @@ search_new (const char *pkgname, upgrade_t *toupgrade[])
 	} /* end installed packages list for() */
 
     
+    dlist_free (&official);
+
     if (opt.use_regex && pkgname)
      regfree (&preg);
     pkg_t_free_all (&packages, npackages);
